@@ -1,6 +1,6 @@
 /* adapter_list.c - python list objects
  *
- * Copyright (C) 2004-2010 Federico Di Gregorio <fog@debian.org>
+ * Copyright (C) 2004-2019 Federico Di Gregorio <fog@debian.org>
  *
  * This file is part of psycopg.
  *
@@ -90,7 +90,9 @@ list_quote(listObject *self)
                      * array[array[]] is */
                     all_nulls = 0;
                     Py_CLEAR(qs[i]);
-                    qs[i] = Bytes_FromString("ARRAY[]");
+                    if (!(qs[i] = Bytes_FromString("ARRAY[]"))) {
+                        goto exit;
+                    }
                 }
             }
             else {
@@ -163,7 +165,7 @@ exit:
 static PyObject *
 list_str(listObject *self)
 {
-    return psycopg_ensure_text(list_quote(self));
+    return psyco_ensure_text(list_quote(self));
 }
 
 static PyObject *
