@@ -1,6 +1,6 @@
 /* adapter_pint.h - definition for the psycopg int type wrapper
  *
- * Copyright (C) 2011 Daniele Varrazzo <daniele.varrazzo@gmail.com>
+ * Copyright (C) 2011-2019 Daniele Varrazzo <daniele.varrazzo@gmail.com>
  *
  * This file is part of psycopg.
  *
@@ -40,12 +40,6 @@ typedef struct {
 
 } pintObject;
 
-/* functions exported to psycopgmodule.c */
-
-HIDDEN PyObject *psyco_Int(PyObject *module, PyObject *args);
-#define psyco_Int_doc \
-    "Int(obj) -> new int value"
-
 #ifdef __cplusplus
 }
 #endif
