@@ -1,6 +1,6 @@
 /* config.h - general config and Dprintf macro
  *
- * Copyright (C) 2003-2010 Federico Di Gregorio <fog@debian.org>
+ * Copyright (C) 2003-2019 Federico Di Gregorio <fog@debian.org>
  *
  * This file is part of psycopg.
  *
@@ -33,6 +33,18 @@
 #  define HIDDEN
 #endif
 
+/* support for getpid() */
+#if defined( __GNUC__)
+#define CONN_CHECK_PID
+#include <sys/types.h>
+#include <unistd.h>
+#endif
+#ifdef _WIN32
+/* Windows doesn't seem affected by bug #829: just make it compile. */
+#define pid_t int
+#endif
+
+
 /* debug printf-like function */
 #ifdef PSYCOPG_DEBUG
 extern HIDDEN int psycopg_debug_enabled;
@@ -40,8 +52,6 @@ extern HIDDEN int psycopg_debug_enabled;
 
 #if defined( __GNUC__) && !defined(__APPLE__)
 #ifdef PSYCOPG_DEBUG
-#include <sys/types.h>
-#include <unistd.h>
 #define Dprintf(fmt, args...) \
     if (!psycopg_debug_enabled) ; else \
         fprintf(stderr, "[%d] " fmt "\n", (int) getpid() , ## args)
@@ -154,8 +164,7 @@ typedef unsigned __int64    uint64_t;
 #endif
 
 /* what's this, we have no round function either? */
-#if (defined(__FreeBSD__) && __FreeBSD_version < 503000) \
-    || (defined(_WIN32) && !defined(__GNUC__)) \
+#if (defined(_WIN32) && !defined(__GNUC__)) \
     || (defined(sun) || defined(__sun__)) \
         && (defined(__SunOS_5_8) || defined(__SunOS_5_9))
 
