@@ -1,6 +1,6 @@
 /* cursor.h - definition for the psycopg cursor type
  *
- * Copyright (C) 2003-2010 Federico Di Gregorio <fog@debian.org>
+ * Copyright (C) 2003-2019 Federico Di Gregorio <fog@debian.org>
  *
  * This file is part of psycopg.
  *
@@ -93,9 +93,10 @@ struct cursorObject {
 /* C-callable functions in cursor_int.c and cursor_type.c */
 BORROWED HIDDEN PyObject *curs_get_cast(cursorObject *self, PyObject *oid);
 HIDDEN void curs_reset(cursorObject *self);
-HIDDEN int psyco_curs_withhold_set(cursorObject *self, PyObject *pyvalue);
-HIDDEN int psyco_curs_scrollable_set(cursorObject *self, PyObject *pyvalue);
-HIDDEN PyObject *psyco_curs_validate_sql_basic(cursorObject *self, PyObject *sql);
+RAISES_NEG HIDDEN int curs_withhold_set(cursorObject *self, PyObject *pyvalue);
+RAISES_NEG HIDDEN int curs_scrollable_set(cursorObject *self, PyObject *pyvalue);
+HIDDEN PyObject *curs_validate_sql_basic(cursorObject *self, PyObject *sql);
+HIDDEN void curs_set_result(cursorObject *self, PGresult *pgres);
 
 /* exception-raising macros */
 #define EXC_IF_CURS_CLOSED(self) \
