@@ -1,6 +1,6 @@
 /* microprotocols.c - minimalist and non-validating protocols implementation
  *
- * Copyright (C) 2003-2010 Federico Di Gregorio <fog@debian.org>
+ * Copyright (C) 2003-2019 Federico Di Gregorio <fog@debian.org>
  *
  * This file is part of psycopg.
  *
@@ -38,15 +38,19 @@ PyObject *psyco_adapters;
 
 /* microprotocols_init - initialize the adapters dictionary */
 
-int
-microprotocols_init(PyObject *dict)
+RAISES_NEG int
+microprotocols_init(PyObject *module)
 {
     /* create adapters dictionary and put it in module namespace */
-    if ((psyco_adapters = PyDict_New()) == NULL) {
+    if (!(psyco_adapters = PyDict_New())) {
         return -1;
     }
 
-    PyDict_SetItemString(dict, "adapters", psyco_adapters);
+    Py_INCREF(psyco_adapters);
+    if (0 > PyModule_AddObject(module, "adapters", psyco_adapters)) {
+        Py_DECREF(psyco_adapters);
+        return -1;
+    }
 
     return 0;
 }
@@ -56,7 +60,7 @@ microprotocols_init(PyObject *dict)
  *
  * Return 0 on success, else -1 and set an exception.
  */
-int
+RAISES_NEG int
 microprotocols_add(PyTypeObject *type, PyObject *proto, PyObject *cast)
 {
     PyObject *key = NULL;
@@ -64,8 +68,6 @@ microprotocols_add(PyTypeObject *type, PyObject *proto, PyObject *cast)
 
     if (proto == NULL) proto = (PyObject*)&isqlquoteType;
 
-    Dprintf("microprotocols_add: cast %p for (%s, ?)", cast, type->tp_name);
-
     if (!(key = PyTuple_Pack(2, (PyObject*)type, proto))) { goto exit; }
     if (0 != PyDict_SetItem(psyco_adapters, key, cast)) { goto exit; }
 
@@ -90,7 +92,7 @@ _get_superclass_adapter(PyObject *obj, PyObject *proto)
 
     type = Py_TYPE(obj);
     if (!(
-#if PY_MAJOR_VERSION < 3
+#if PY_2
         (Py_TPFLAGS_HAVE_CLASS & type->tp_flags) &&
 #endif
         type->tp_mro)) {
