@@ -1,6 +1,6 @@
 /* typecast_datetime.c - date and time typecasting functions to python types
  *
- * Copyright (C) 2001-2010 Federico Di Gregorio <fog@debian.org>
+ * Copyright (C) 2001-2019 Federico Di Gregorio <fog@debian.org>
  *
  * This file is part of psycopg.
  *
@@ -27,10 +27,8 @@
 #include "datetime.h"
 
 RAISES_NEG static int
-psyco_typecast_datetime_init(void)
+typecast_datetime_init(void)
 {
-    Dprintf("psyco_typecast_datetime_init: datetime init");
-
     PyDateTime_IMPORT;
 
     if (!PyDateTimeAPI) {
@@ -406,6 +404,11 @@ typecast_PYINTERVAL_cast(const char *str, Py_ssize_t len, PyObject *curs)
             }
             break;
 
+        case 'P':
+            PyErr_SetString(NotSupportedError,
+                "iso_8601 intervalstyle currently not supported");
+            return NULL;
+
         default:
             break;
         }
@@ -453,10 +456,8 @@ typecast_PYINTERVAL_cast(const char *str, Py_ssize_t len, PyObject *curs)
 
 /* psycopg defaults to using python datetime types */
 
-#ifdef PSYCOPG_DEFAULT_PYDATETIME
 #define typecast_DATE_cast typecast_PYDATE_cast
 #define typecast_TIME_cast typecast_PYTIME_cast
 #define typecast_INTERVAL_cast typecast_PYINTERVAL_cast
 #define typecast_DATETIME_cast typecast_PYDATETIME_cast
 #define typecast_DATETIMETZ_cast typecast_PYDATETIMETZ_cast
-#endif
