@@ -39,8 +39,20 @@ create () {
 
     # install postgres versions not available on the image
     if [[ ! -d "${PGDIR}" ]]; then
-        wget -O - http://initd.org/psycopg/upload/postgresql/postgresql-${PACKAGE}-$(lsb_release -cs).tar.bz2 \
-            | sudo tar xjf - -C /usr/lib/postgresql
+        if (( "$VERNUM" >= 904 )); then
+            # A versiou supported by postgres
+            if [[ ! "${apt_updated:-}" ]]; then
+                apt_updated="yeah"
+                sudo apt-get update -y
+            fi
+            sudo apt-get install -y \
+                postgresql-server-dev-${VERSION} postgresql-${VERSION}
+        else
+            # A dinosaur
+            wget -O - \
+                http://initd.org/psycopg/upload/postgresql/postgresql-${PACKAGE}-$(lsb_release -cs).tar.bz2 \
+                | sudo tar xjf - -C /usr/lib/postgresql
+        fi
     fi
 
     sudo -u postgres "$PGBIN/initdb" -D "$DATADIR"
@@ -104,7 +116,9 @@ create () {
 cd /
 
 # Postgres versions supported by Travis CI
-if [[ -z "$DONT_TEST_PRESENT" ]]; then
+if (( ! "$DONT_TEST_PRESENT" )); then
+    create 12
+    create 11
     create 10
     create 9.6
     create 9.5
@@ -113,7 +127,7 @@ fi
 
 # Unsupported postgres versions that we still support
 # Images built by https://github.com/psycopg/psycopg2-wheels/tree/build-dinosaurs
-if [[ -n "$TEST_PAST" ]]; then
+if (( "$TEST_PAST" )); then
     create 7.4
     create 8.0
     create 8.1
@@ -127,6 +141,6 @@ if [[ -n "$TEST_PAST" ]]; then
 fi
 
 # Postgres built from master
-if [[ -n "$TEST_FUTURE" ]]; then
-    create 11 11-master
+if (( "$TEST_FUTURE" )); then
+    create 13 13-master
 fi
