@@ -3,7 +3,7 @@
 
 # test_cancel.py - unit test for query cancellation
 #
-# Copyright (C) 2010-2011 Jan Urbański  <wulczer@wulczer.org>
+# Copyright (C) 2010-2019 Jan Urbański  <wulczer@wulczer.org>
 #
 # psycopg2 is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published
@@ -30,8 +30,9 @@ import psycopg2
 import psycopg2.extensions
 from psycopg2 import extras
 
-from testconfig import dsn
-from testutils import unittest, ConnectingTestCase, skip_before_postgres, slow
+from .testconfig import dsn
+import unittest
+from .testutils import ConnectingTestCase, skip_before_postgres, slow
 
 
 class CancelTests(ConnectingTestCase):
@@ -113,5 +114,6 @@ class CancelTests(ConnectingTestCase):
 def test_suite():
     return unittest.TestLoader().loadTestsFromName(__name__)
 
+
 if __name__ == "__main__":
     unittest.main()
