@@ -2,7 +2,7 @@
 #
 # test_fast_executemany.py - tests for fast executemany implementations
 #
-# Copyright (C) 2017 Daniele Varrazzo  <daniele.varrazzo@gmail.com>
+# Copyright (C) 2017-2019 Daniele Varrazzo  <daniele.varrazzo@gmail.com>
 #
 # psycopg2 is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published
@@ -16,12 +16,13 @@
 
 from datetime import date
 
-import testutils
-from testutils import unittest
+from . import testutils
+import unittest
 
 import psycopg2
 import psycopg2.extras
 import psycopg2.extensions as ext
+from psycopg2 import sql
 
 
 class TestPaginate(unittest.TestCase):
@@ -84,7 +85,6 @@ class TestExecuteBatch(FastExecuteTestMixin, testutils.ConnectingTestCase):
         self.assertEqual(cur.fetchall(), [(i, i * 10) for i in range(1000)])
 
     def test_composed(self):
-        from psycopg2 import sql
         cur = self.conn.cursor()
         psycopg2.extras.execute_batch(cur,
             sql.SQL("insert into {0} (id, val) values (%s, %s)")
@@ -134,6 +134,7 @@ class TestExecuteBatch(FastExecuteTestMixin, testutils.ConnectingTestCase):
         self.assertEqual(cur.fetchone(), (3, snowman))
 
 
+@testutils.skip_before_postgres(8, 2)
 class TestExecuteValues(FastExecuteTestMixin, testutils.ConnectingTestCase):
     def test_empty(self):
         cur = self.conn.cursor()
@@ -180,7 +181,6 @@ class TestExecuteValues(FastExecuteTestMixin, testutils.ConnectingTestCase):
         self.assertEqual(cur.fetchall(), [(i, i * 10) for i in range(1000)])
 
     def test_composed(self):
-        from psycopg2 import sql
         cur = self.conn.cursor()
         psycopg2.extras.execute_values(cur,
             sql.SQL("insert into {0} (id, val) values %s")
@@ -228,6 +228,15 @@ class TestExecuteValues(FastExecuteTestMixin, testutils.ConnectingTestCase):
         cur.execute("select id, data from testfast where id = 3")
         self.assertEqual(cur.fetchone(), (3, snowman))
 
+    def test_returning(self):
+        cur = self.conn.cursor()
+        result = psycopg2.extras.execute_values(cur,
+            "insert into testfast (id, val) values %s returning id",
+            ((i, i * 10) for i in range(25)),
+            page_size=10, fetch=True)
+        # result contains all returned pages
+        self.assertEqual([r[0] for r in result], list(range(25)))
+
     def test_invalid_sql(self):
         cur = self.conn.cursor()
         self.assertRaises(ValueError, psycopg2.extras.execute_values, cur,
@@ -251,12 +260,9 @@ class TestExecuteValues(FastExecuteTestMixin, testutils.ConnectingTestCase):
         self.assertEqual(cur.fetchall(), [(1, 'hi')])
 
 
-testutils.decorate_all_tests(TestExecuteValues,
-    testutils.skip_before_postgres(8, 2))
-
-
 def test_suite():
     return unittest.TestLoader().loadTestsFromName(__name__)
 
+
 if __name__ == "__main__":
     unittest.main()
