@@ -2,7 +2,7 @@
 
 # test_ctxman.py - unit test for connection and cursor used as context manager
 #
-# Copyright (C) 2012 Daniele Varrazzo  <daniele.varrazzo@gmail.com>
+# Copyright (C) 2012-2019 Daniele Varrazzo  <daniele.varrazzo@gmail.com>
 #
 # psycopg2 is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published
@@ -22,13 +22,11 @@
 # FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 # License for more details.
 
-
-from __future__ import with_statement
-
 import psycopg2
 import psycopg2.extensions as ext
 
-from testutils import unittest, ConnectingTestCase, skip_before_postgres
+import unittest
+from .testutils import ConnectingTestCase, skip_before_postgres
 
 
 class WithTestCase(ConnectingTestCase):
@@ -219,12 +217,13 @@ class WithCursorTestCase(WithTestCase):
 
     @skip_before_postgres(8, 2)
     def test_named_with_noop(self):
-        with self.conn.cursor('named') as cur:
+        with self.conn.cursor('named'):
             pass
 
 
 def test_suite():
     return unittest.TestLoader().loadTestsFromName(__name__)
 
+
 if __name__ == "__main__":
     unittest.main()
